==> core-react-0.8.0.tgz: package/es/Nav/SubNav.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';

var SubNav = /*#__PURE__*/function (_React$Component) {
  _inherits(SubNav, _React$Component);

  function SubNav(props) {
    var _this;

    _classCallCheck(this, SubNav);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SubNav).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleToggle", function (e) {
      e.preventDefault();

      _this.setState({
        open: !_this.state.open
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      if (_this.context.nav.state.collapsed) {
        _this.context.nav.setState({
          collapsed: false,
          collapsedTrigger: 'sub-nav-icon'
        });

        _this.setState({
          open: true
        });
      }

      _this.props.onClick && _this.props.onClick(e);
    });

    _defineProperty(_assertThisInitialized(_this), "activateOrOpenSubNav", function (_ref) {
      var _ref$nav$state = _ref.nav.state,
          selectedId = _ref$nav$state.selectedId,
          collapsedTrigger = _ref$nav$state.collapsedTrigger;

      if (!Array.isArray(_this.props.children)) {
        return;
      }

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = _this.props.children[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var child = _step.value;

          if (child.type.name === 'NavItem') {
            if (child.props.id === selectedId) {
              // Make the current SubNav active if one of children is active
              _this.setState({
                active: true
              }); // Make the active NavItem's corresponding SubNav open if click menu icon


              !_this.state.open && collapsedTrigger === 'menu-icon' && _this.setState({
                open: true
              });
              return;
            }
          }

          if (child.type.name === 'NavItemGroup') {
            var _iteratorNormalCompletion2 = true;
            var _didIteratorError2 = false;
            var _iteratorError2 = undefined;

            try {
              for (var _iterator2 = child.props.children[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
                var item = _step2.value;

                if (item.props.id === selectedId) {
                  // Make the current SubNav active if one of children is active
                  _this.setState({
                    active: true
                  }); // Make the active NavItem's corresponding SubNav open if click menu icon


                  !_this.state.open && collapsedTrigger === 'menu-icon' && _this.setState({
                    open: true
                  });
                  return;
                }
              }
            } catch (err) {
              _didIteratorError2 = true;
              _iteratorError2 = err;
            } finally {
              try {
                if (!_iteratorNormalCompletion2 && _iterator2["return"] != null) {
                  _iterator2["return"]();
                }
              } finally {
                if (_didIteratorError2) {
                  throw _iteratorError2;
                }
              }
            }
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator["return"] != null) {
            _iterator["return"]();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      _this.setState({
        active: false
      });
    });

    _this.state = {
      open: false,
      active: false
    };
    return _this;
  }

  _createClass(SubNav, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(nextProps, nextState) {
      // Close all sub navs when click close-icon button on the right top
      if (this.context.nav.state.collapsed && this.state.open) {
        this.setState({
          open: false
        });
      }
    }
  }, {
    key: "componentWillReceiveProps",

    /**
     * Called by props and context changes such as `this.context.nav`
     */
    value: function componentWillReceiveProps(nextProps, nextContext) {
      this.activateOrOpenSubNav(nextContext);
    }
    /**
     * Called after the component mounted
     */

  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.activateOrOpenSubNav(this.context);
    }
  }, {
    key: "render",
    value: function render() {
      var _cx;

      var _this$state = this.state,
          open = _this$state.open,
          active = _this$state.active;

      var _this$props = this.props,
          className = _this$props.className,
          icon = _this$props.icon,
          title = _this$props.title,
          children = _this$props.children,
          other = _objectWithoutProperties(_this$props, ["className", "icon", "title", "children"]);

      var SubNavIcon = /\//.test(icon) ? React.createElement(Icon, {
        className: "".concat("waui", "-nav__sub-nav-title-icon"),
        src: icon
      }) : React.createElement(Icon, {
        type: icon,
        className: "".concat("waui", "-nav__sub-nav-title-icon")
      }); // Child nodes are no longer rendered when the nav item is closed.

      return React.createElement("li", _extends({
        onClick: this.handleClick,
        className: cx("".concat("waui", "-nav__sub-nav"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-nav__sub-nav--open"), open), _defineProperty(_cx, "".concat("waui", "-nav__sub-nav--active"), active), _cx), className)
      }, other), React.createElement("div", {
        className: "".concat("waui", "-nav__sub-nav-title"),
        onClick: this.handleToggle
      }, SubNavIcon, React.createElement("span", null, title, React.createElement(Icon, {
        type: "triangleright",
        className: "".concat("waui", "-nav__sub-nav-title-toggle")
      }))), open && children && React.createElement("ul", null, children));
    }
  }]);

  return SubNav;
}(React.Component);

SubNav.contextTypes = {
  nav: PropTypes.object
};
SubNav.propTypes = {
  className: PropTypes.string,

  /* The children of SubNav which can be NavItem or NavItemGroup */
  children: PropTypes.node,

  /* The title of SubNav which can be a text string or a React element */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /* The click event of each SubNav */
  onClick: PropTypes.func,

  /* SubNav icon, support `Icon` component or svg url */
  icon: PropTypes.string
};
export default SubNav;

==> core-react-0.8.2.tgz: package/es/Nav/SubNav.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';

var SubNav = /*#__PURE__*/function (_React$Component) {
  _inherits(SubNav, _React$Component);

  function SubNav(props) {
    var _this;

    _classCallCheck(this, SubNav);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(SubNav).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleToggle", function (e) {
      e.preventDefault();

      _this.setState({
        open: !_this.state.open
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (e) {
      if (_this.context.nav.state.collapsed) {
        _this.context.nav.setState({
          collapsed: false,
          collapsedTrigger: 'sub-nav-icon'
        });

        _this.setState({
          open: true
        });
      }

      _this.props.onClick && _this.props.onClick(e);
    });

    _defineProperty(_assertThisInitialized(_this), "activateOrOpenSubNav", function (_ref) {
      var _ref$nav$state = _ref.nav.state,
          selectedId = _ref$nav$state.selectedId,
          collapsedTrigger = _ref$nav$state.collapsedTrigger;

      if (!Array.isArray(_this.props.children)) {
        return;
      }

      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = _this.props.children[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var child = _step.value;

          if (child.type.name === 'NavItem') {
            if (child.props.id === selectedId) {
              // Make the current SubNav active if one of children is active
              _this.setState({
                active: true
              }); // Make the active NavItem's corresponding SubNav open if click menu icon


              !_this.state.open && collapsedTrigger === 'menu-icon' && _this.setState({
                open: true
              });
              return;
            }
          }

          if (child.type.name === 'NavItemGroup') {
            var _iteratorNormalCompletion2 = true;
            var _didIteratorError2 = false;
            var _iteratorError2 = undefined;

            try {
              for (var _iterator2 = child.props.children[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
                var item = _step2.value;

                if (item.props.id === selectedId) {
                  // Make the current SubNav active if one of children is active
                  _this.setState({
                    active: true
                  }); // Make the active NavItem's corresponding SubNav open if click menu icon


                  !_this.state.open && collapsedTrigger === 'menu-icon' && _this.setState({
                    open: true
                  });
                  return;
                }
              }
            } catch (err) {
              _didIteratorError2 = true;
              _iteratorError2 = err;
            } finally {
              try {
                if (!_iteratorNormalCompletion2 && _iterator2["return"] != null) {
                  _iterator2["return"]();
                }
              } finally {
                if (_didIteratorError2) {
                  throw _iteratorError2;
                }
              }
            }
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator["return"] != null) {
            _iterator["return"]();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      _this.setState({
        active: false
      });
    });

    _this.state = {
      open: false,
      active: false
    };
    return _this;
  }

  _createClass(SubNav, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(nextProps, nextState) {
      // Close all sub navs when click close-icon button on the right top
      if (this.context.nav.state.collapsed && this.state.open) {
        this.setState({
          open: false
        });
      }
    }
  }, {
    key: "componentWillReceiveProps",

    /**
     * Called by props and context changes such as `this.context.nav`
     */
    value: function componentWillReceiveProps(nextProps, nextContext) {
      this.activateOrOpenSubNav(nextContext);
    }
    /**
     * Called after the component mounted
     */

  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.activateOrOpenSubNav(this.context);
    }
  }, {
    key: "render",
    value: function render() {
      var _cx;

      var _this$state = this.state,
          open = _this$state.open,
          active = _this$state.active;

      var _this$props = this.props,
          className = _this$props.className,
          icon = _this$props.icon,
          title = _this$props.title,
          children = _this$props.children,
          other = _objectWithoutProperties(_this$props, ["className", "icon", "title", "children"]);

      var SubNavIcon = /\//.test(icon) ? /*#__PURE__*/React.createElement(Icon, {
        className: "".concat("waui", "-nav__sub-nav-title-icon"),
        src: icon
      }) : /*#__PURE__*/React.createElement(Icon, {
        type: icon,
        className: "".concat("waui", "-nav__sub-nav-title-icon")
      }); // Child nodes are no longer rendered when the nav item is closed.

      return (/*#__PURE__*/React.createElement("li", _extends({
          onClick: this.handleClick,
          className: cx("".concat("waui", "-nav__sub-nav"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-nav__sub-nav--open"), open), _defineProperty(_cx, "".concat("waui", "-nav__sub-nav--active"), active), _cx), className)
        }, other), /*#__PURE__*/React.createElement("div", {
          className: "".concat("waui", "-nav__sub-nav-title"),
          onClick: this.handleToggle
        }, SubNavIcon, /*#__PURE__*/React.createElement("span", null, title, /*#__PURE__*/React.createElement(Icon, {
          type: "triangleright",
          className: "".concat("waui", "-nav__sub-nav-title-toggle")
        }))), open && children && /*#__PURE__*/React.createElement("ul", null, children))
      );
    }
  }]);

  return SubNav;
}(React.Component);

SubNav.contextTypes = {
  nav: PropTypes.object
};
SubNav.propTypes = {
  className: PropTypes.string,

  /* The children of SubNav which can be NavItem or NavItemGroup */
  children: PropTypes.node,

  /* The title of SubNav which can be a text string or a React element */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /* The click event of each SubNav */
  onClick: PropTypes.func,

  /* SubNav icon, support `Icon` component or svg url */
  icon: PropTypes.string
};
export default SubNav;
